@@ -19,8 +19,7 @@ if ( $has_proc_pid_file and $has_home_dir ) {
 use FindBin qw/$Bin/;
 use File::Spec;
 use lib File::Spec->catdir( $FindBin::Bin, '..', '..', 'lib' );
-use Foorum::XUtils qw/config base_path/;
-use Foorum::CronUtils qw/theschwartz/;
+use Foorum::XUtils qw/config base_path theschwartz/;
 
 my $config = config();
 
