@@ -42,7 +42,7 @@ sub create : Regex('^forum/(\w+)/poll/new$') {
     $multi = 0 if ( $multi ne '1' );    # 0 or 1
 
     my $now = time();
-    $duration = $now + $duration * 86400;    # 86400 = 24 * 60 * 60, means 1 day
+    $duration = $now + $duration * 86400;  # 86400 = 24 * 60 * 60, means 1 day
 
     # we prefer [% | html %] now because of my bad memory in TT html
     my $title = $c->req->param('title');
@@ -88,8 +88,8 @@ sub poll : Regex('^forum/(\w+)/poll/(\d+)$') {
     my $forum_id   = $forum->{forum_id};
     my $poll_id    = $c->req->snippets->[1];
 
-    my $poll = $c->model('DBIC::Poll')
-        ->find( { poll_id => $poll_id, }, { prefetch => [ 'author', 'options' ], } );
+    my $poll = $c->model('DBIC::Poll')->find( { poll_id => $poll_id, },
+        { prefetch => [ 'author', 'options' ], } );
 
     my $can_vote = 0;
     if ( time() < $poll->duration and $c->user_exists ) {
@@ -115,8 +115,8 @@ sub poll : Regex('^forum/(\w+)/poll/(\d+)$') {
         );
 
     # register hit
-    $poll->{_column_data}->{hit}
-        = $c->model('DBIC::Hit')->register( 'poll', $poll->poll_id, $poll->hit );
+    $poll->{_column_data}->{hit} = $c->model('DBIC::Hit')
+        ->register( 'poll', $poll->poll_id, $poll->hit );
 
     $c->stash(
         {   can_vote => $can_vote,
