@@ -30,7 +30,8 @@ sub get_object_from_url {
         if ( $user_sig =~ /^\d+$/ ) {
             $object_id = $user_sig;
         } else {
-            my $user = $c->model('DBIC::User')->get( { username => $user_sig } );
+            my $user
+                = $c->model('DBIC::User')->get( { username => $user_sig } );
             return unless ($user);
             $object_id = $user->{user_id};
         }
@@ -70,20 +71,23 @@ sub get_object_by_type_id {
             object_type => 'topic',
             object_id   => $object_id,
             title       => $object->{title},
-            author => $c->model('DBIC::User')->get( { user_id => $object->{author_id} } ),
-            url    => '/forum/' . $object->{forum_id} . "/$object_id",
+            author      => $c->model('DBIC::User')
+                ->get( { user_id => $object->{author_id} } ),
+            url         => '/forum/' . $object->{forum_id} . "/$object_id",
             last_update => $object->{last_update_date},
             forum_id    => $object->{forum_id},
         };
     } elsif ( $object_type eq 'poll' ) {
-        my $object = $c->model('DBIC::Poll')->find( { poll_id => $object_id, } );
+        my $object
+            = $c->model('DBIC::Poll')->find( { poll_id => $object_id, } );
         return unless ($object);
         return {
             object_type => 'poll',
             object_id   => $object_id,
             title       => $object->title,
-            author => $c->model('DBIC::User')->get( { user_id => $object->author_id } ),
-            url    => '/forum/' . $object->forum_id . "/poll/$object_id",
+            author      => $c->model('DBIC::User')
+                ->get( { user_id => $object->author_id } ),
+            url         => '/forum/' . $object->forum_id . "/poll/$object_id",
             last_update => '-',
             forum_id    => $object->forum_id,
         };
