@@ -37,7 +37,8 @@ sub get_multi {
     my @mem_keys;
     my %val_map_key;
     foreach (@$val) {
-        my $cache_key = 'user|' . Object::Signature::signature( { $key => $_ } );
+        my $cache_key
+            = 'user|' . Object::Signature::signature( { $key => $_ } );
         push @mem_keys, $cache_key;
         $val_map_key{$_} = $cache_key;
     }
@@ -58,7 +59,8 @@ sub get_multi {
         } else {
             $return_users{$v} = $self->get_from_db( { $key => $v } );
             next unless ( $return_users{$v} );
-            $cache->set( $val_map_key{$v}, $return_users{$v}, 7200 );    # two hours
+            $cache->set( $val_map_key{$v}, $return_users{$v}, 7200 )
+                ;    # two hours
         }
     }
 
@@ -75,32 +77,32 @@ sub get_from_db {
     return unless ($user);
 
     # user_details
-    my $user_details
-        = $schema->resultset('UserDetails')->find( { user_id => $user->user_id } );
+    my $user_details = $schema->resultset('UserDetails')
+        ->find( { user_id => $user->user_id } );
     $user_details = $user_details->{_column_data} if ($user_details);
 
     # user role
-    my @roles
-        = $schema->resultset('UserRole')->search( { user_id => $user->user_id, } )->all;
+    my @roles = $schema->resultset('UserRole')
+        ->search( { user_id => $user->user_id, } )->all;
     my $roles;
     foreach (@roles) {
         $roles->{ $_->field }->{ $_->role } = 1;
     }
-    my @forum_roles
-        = $schema->resultset('UserForum')->search( { user_id => $user->user_id } )->all;
+    my @forum_roles = $schema->resultset('UserForum')
+        ->search( { user_id => $user->user_id } )->all;
     foreach (@forum_roles) {
         $roles->{ $_->forum_id }->{ $_->status } = 1;
     }
 
     # user profile photo
-    my $profile_photo
-        = $schema->resultset('UserProfilePhoto')->find( { user_id => $user->user_id, } );
+    my $profile_photo = $schema->resultset('UserProfilePhoto')
+        ->find( { user_id => $user->user_id, } );
     if ($profile_photo) {
         $profile_photo = $profile_photo->{_column_data};
         if ( $profile_photo->{type} eq 'upload' ) {
 
-            my $profile_photo_upload
-                = $schema->resultset('Upload')->get( $profile_photo->{value} );
+            my $profile_photo_upload = $schema->resultset('Upload')
+                ->get( $profile_photo->{value} );
             $profile_photo->{upload} = $profile_photo_upload
                 if ($profile_photo_upload);
         }
@@ -123,10 +125,13 @@ sub delete_cache_by_user {
 
     my @ckeys;
     push @ckeys,
-        'user|' . Object::Signature::signature( { user_id => $user->{user_id} } );
+        'user|'
+        . Object::Signature::signature( { user_id => $user->{user_id} } );
     push @ckeys,
-        'user|' . Object::Signature::signature( { username => $user->{username} } );
-    push @ckeys, 'user|' . Object::Signature::signature( { email => $user->{email} } );
+        'user|'
+        . Object::Signature::signature( { username => $user->{username} } );
+    push @ckeys,
+        'user|' . Object::Signature::signature( { email => $user->{email} } );
 
     foreach my $ckey (@ckeys) {
         $cache->remove($ckey);
@@ -169,7 +174,8 @@ sub update_threads_and_replies {
         }
     );
 
-    $self->update_user( $user, { threads => $total - $replies, replies => $replies } );
+    $self->update_user( $user,
+        { threads => $total - $replies, replies => $replies } );
 }
 
 # get user_settings
@@ -193,7 +199,8 @@ sub get_user_settings {
         while ( my $rs = $settings_rs->next ) {
             $cacheval->{ $rs->type } = $rs->value;
         }
-        $cache->set( $cachekey, { val => $cacheval, 1 => 2 } );    # for empty $cacheval
+        $cache->set( $cachekey, { val => $cacheval, 1 => 2 } )
+            ;    # for empty $cacheval
     }
 
     # if not stored in db, we use default value;
@@ -201,7 +208,7 @@ sub get_user_settings {
         'send_starred_notification' => 'Y',
         'show_email_public'         => 'Y',
     };
-    my $ret = { %$default, %$cacheval };                           # merge
+    my $ret = { %$default, %$cacheval };    # merge
     return $ret;
 }
 
@@ -218,7 +225,8 @@ sub validate_username {
     my $schema = $self->result_source->schema;
 
     # username_reserved
-    my @reserved = $schema->resultset('FilterWord')->get_data('username_reserved');
+    my @reserved
+        = $schema->resultset('FilterWord')->get_data('username_reserved');
     return 'HAS_RESERVED' if ( grep { lc($username) eq lc($_) } @reserved );
 
     # unique
