@@ -23,6 +23,13 @@ __PACKAGE__->add_columns(
   },
   "time",
   { data_type => "INT", default_value => 0, is_nullable => 0, size => 11 },
+  "note",
+  {
+    data_type => "VARCHAR",
+    default_value => undef,
+    is_nullable => 1,
+    size => 255,
+  },
 );
 __PACKAGE__->set_primary_key("security_code_id");
 
